<?php

/*
Plugin Name: Gravity Forms Online Success software API Add-On
Description: This plugin allows Gravity Forms to send data directly to the Online Success software API
Version: 1.0
Version date: 19/06/2014
Author: Online Succes B.V.
Author URI: http://www.onlinesucces.nl

Supported Gravity Forms field types:
	Single Line Text
	Paragraph Text
	Hidden
	Drop Down
	Multi Select
	Number
	Checkboxes
	Radio Buttons
	Name
	Date
	Time
	Phone
	Website
	Email
	Address
	
Unsupported Gravity Forms field types:
	File Upload
	List
*/

/*
Copyright 2014 Online Succes B.V.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


add_action('init',  array('OS6LeadManagerAPI', 'init'));

class OS6LeadManagerAPI {

private static $name = "Gravity Forms Online Success software Add-On";
private static $path = "gravity-forms-os6-lead-manager-api-add-on/gravity-forms-online-succes.php";
private static $version = "0.1";
private static $min_gravityforms_version = "1.6";  // I'm specifying 1.6 in case we decide to change from gform_pre_submission to gform_after_submission


//Plugin starting point. Will load appropriate files
public static function init(){

	add_action("admin_notices", array('OS6LeadManagerAPI', 'display_gravity_forms_status'));

   if( !self::is_gravityforms_supported()){
	   return;
	}
	
	$plugin_file = self::$path;
	add_filter( "plugin_action_links_{$plugin_file}", array('OS6LeadManagerAPI', 'plugin_settings_link'), 10, 2 );

	if(is_admin()){  //creates a new Settings page on Gravity Forms' settings screen
			RGForms::add_settings_page("Online Success software API", array("OS6LeadManagerAPI", "lb_settings_page") );
	}
	
	add_action("gform_pre_submission", Array( "OS6LeadManagerAPI", "lb_gform_pre_submission" ) );
	
}  // end of init()
    


public static function lb_settings_page(){

	if(!empty($_POST["uninstall"])){
		check_admin_referer("deactivate", "os6_lead_manager_deactivate");
		self::deactivate();
		?>
		<div class="updated fade" style="padding:20px;">The Online Success software Gravity Forms add-on has been successfully uninstalled. It can be re-activated from the <a href='plugins.php'>plugins page</a>.</div>
		<?php
		return;
	} elseif(!empty($_POST["os6_lead_manager_submit"])){
		check_admin_referer("update", "os6_lead_manager_update");
		$settings = array(
			"key" => stripslashes($_POST["os6_lead_manager_api_key"]), 
			"clientid" => stripslashes($_POST["os6_lead_manager_clientid"]), 
			"date_format" => stripslashes($_POST["os6_lead_manager_date_format"]), 
			"decimal_separator" => stripslashes($_POST["os6_lead_manager_decimal_separator"]), 
			"debug" => stripslashes($_POST["os6_lead_manager_debug"])
			);
		$forms = RGFormsModel::get_forms();

		$arrFields = array();
		foreach($forms as $form) {
			if($form->is_active == 1) {
				//echo '<b>'.$form->title.'</b><br>';
				$form_id = $form->id;
				$form_fields = self::get_form_fields($form_id);

				foreach($form_fields as $field){
					$field_id = $field[0];
					$field_label = $field[1];		
					if (strlen($_REQUEST[$form_id."|".$field_id])>0) {
						$arrFields[$form_id."|".$field_id] = $_REQUEST[$form_id."|".$field_id];
						//array_push($settings, array($form_id."|".$field_id => $_REQUEST[$form_id."|".$field_id]));
					}
					//echo $_REQUEST[$form_id."|".$field_id]."!<BR>";
				}
			}
		}
		$settings = array_merge($settings, $arrFields);		
		//print_r($settings);
		update_option("os6_lead_manager_settings", $settings);		
	}
	else{
		$settings = get_option("os6_lead_manager_settings");
	}

	if ($settings["key"] == '') {
		$api_test_message = "";
	/*
	} elseif ( self::lb_test_account( $api_test_message ) ) {
		$api_test_message = "<p style='display:block;margin-top:10px;color:green;'>Account confirmed</p>";
	*/
	} else {
		$api_test_message = "<p style='display:block;margin-top:10px;color:red;'>".$api_test_message."</p>";
	}

	?>
	<div class="wrap">
	<h2>Online Success software API Setup</h2>

	<div class="hr-divider"></div>

	<h3>Using the Gravity Forms Online Success software API add on</h3>
	<p>To send data to the Online Success software API, you need to associate the fields in your forms with parameters that the Online Success software API recognises.</p>

	<p>To do this, configure the Gravity Form settings to match the Online Success software fields in the dropdowns. Any fields in your forms that do not have a field match set, will be ignored.</p>

	<div class="hr-divider"></div>

	<form method="post" action="" style="margin: 30px 0 30px; clear:both;">
		<?php wp_nonce_field("update", "os6_lead_manager_update") ?>
		<h3>Your Online Success software Account</h3>
		<p>If you don't have a subscription to the Online Success software services, you can <a href='http://www.onlinesucces.nl' target='_blank'>sign up for one here</a>.</p>

		<table class="form-table">
			<tr>
				<th scope="row"><label for="os6_lead_manager_api_key">API Key</label></th>
				<td>
					<input type="text" size="75" id="os6_lead_manager_api_key" class="code pre" name="os6_lead_manager_api_key" value="<?php echo esc_attr($settings["key"]) ?>"/>
					<small style="display:block;">You can find your Online Succes API key by logging into your account <a href='https://app.onlinesucces.nl' target='_blank'>on our website</a> at your company profile.</small>
					<?php print $api_test_message;?>
				</td>
			</tr>

			<tr>
				<th scope="row"><label for="os6_lead_manager_clientid">Client ID</label></th>
				<td>
					<input type="text" size="10" id="os6_lead_manager_clientid" class="code pre" name="os6_lead_manager_clientid" value="<?php echo esc_attr($settings["clientid"]) ?>"/>
					<small style="display:block;">You can find your Online Success software Client ID by logging into your account <a href='https://app.onlinesucces.nl' target='_blank'>on our website</a> at your company profile.</small>
					<?php print $clientid_test_message;?>
				</td>
			</tr>


			<tr>
				<th scope="row"><label for="os6_lead_manager_clientid"><?php _e('Your active forms', "gravity-forms-os6"); ?></label></th>
				<td>
				<?php
				$forms = RGFormsModel::get_forms();

				foreach($forms as $form) {
					if($form->is_active == 1) {
						echo '<b>'.$form->title.'</b><br>';
						$form_id = $form->id;

						//getting list of all OS6 merge variables for the selected contact list
						$merge_vars = @self::getFieldsForObject();

						//getting field map UI
						$str = self::get_field_mapping($config, $form_id, $merge_vars, $settings);						
						echo $str;
					}
				}
				?>
			</td>
		</tr>

			
			<tr>
				<th scope="row">Debugging</th>
				<td>
				<label for="os6_lead_manager_debug">
					<?php if( isset($settings["debug"]) && ($settings["debug"] == 'on' ) ) { 
						print "<input name='os6_lead_manager_debug' type='checkbox' id='os6_lead_manager_debug' checked>"; 
					} else { 
						print "<input name='os6_lead_manager_debug' type='checkbox' id='os6_lead_manager_debug'>"; 
					} ?>
					Email debugging logs to your WordPress admin email address.
				</label>
				<small style="display:block;">(n.b. this option should only be turned on to help Online Succes B.V. diagnose any problems you have with sending data to the Online Success software API)</small>
				</td>
			</tr>
			<tr>
				<td colspan="2" ><input type="submit" name="os6_lead_manager_submit" class="submit button-primary" value="Update Settings" /></td>
			</tr>
		</table>
	</form>

	<div class="hr-divider"></div>

	<form action="" method="post">
		<?php wp_nonce_field("deactivate", "os6_lead_manager_deactivate") ?>

		<h3>Deactivate Online Success software API add-on</h3>
		<div class="delete-alert alert_red">
			<h3>Warning</h3>
			<p>Deactivating the Online Success software API add-on for Gravity Forms will mean that your forms will no longer submit data to the Online Success software API.</p>
			<input type="submit" name="uninstall" value="Deactivate Online Success software API Add-On" class="button" onclick="return confirm(\'Really deactivate the Online Success software add-on?\');"/>
		</div>
	</form>


	</div>
	<?php
}



public static function lb_test_account( &$message ) {
	
	$settings = get_option("os6_lead_manager_settings");
	$submitted_data = Array();
	$submitted_data["Key"] = $settings["key"];
	
	// Post the submitted values to the Online Success software API account check script
	$response = wp_remote_post( "https://app.onlinesucces.nl/api/apiCheck.php", array(
		'method' => 'POST',
		'timeout' => 45,
		'redirection' => 5,
		'body' => $submitted_data,
		)
	);
	
	if ( is_wp_error( $response ) ) {
		$message = "WordPress error: ".$response->get_error_message();
		Return False;
	} else {
		if ( $response["response"]["code"] == 200 ) {
			$status_array = Explode( Chr(13), $response["body"] );
			if( $status_array[0] == 0 ) {
				$message = $status_array[1];
				Return True;
			} else {
				$message = $status_array[1];
				Return False;
			}
		}
	}

}


public static function lb_gform_pre_submission( $form ) {
	$submitted_data = array();
	$settings = get_option("os6_lead_manager_settings");

	$strDebugMail = get_option('admin_email');
	//$strDebugMail = "frank@onlinesucces.nl";


	if( isset($settings["debug"]) && ($settings["debug"] == 'on' ) ) {  // Send debugging email
		ob_start();
		var_dump($form);
		mail( $strDebugMail, '1 Online Success software API for Gravity Forms $form', ob_get_contents() );
		ob_end_clean();
		ob_start();
		var_dump($_POST);
		mail( $strDebugMail, '2 Online Success software API for Gravity Forms $_POST', ob_get_contents() );
		ob_end_clean();
	}
	

	// Build up an array of values submitted via the form
	foreach( $form["fields"] as $field) {
		$label = "";
		$value = "";

		if( is_array( $field["inputs"] ) ) {  // This is multi-input field, like the name field.
			if( $field["type"] == "checkbox" ) {
				if( isset( $field["inputName"] ) && ($field["inputName"] != '') ) {
					$label = $field["inputName"];
					foreach( $field["inputs"] as $input ) {
						if( isset( $_POST["input_".str_replace( '.', '_', $input["id"] )] ) ) {
							if( $value != '' ) { $value .= Chr(13); }
							$value .= stripslashes( $_POST["input_".str_replace('.', '_', $input["id"] )] );
						}
				   }	
				}
			} else {
				foreach( $field["inputs"] as $input ) {
					if( isset( $input["name"] ) && ($input["name"] != '') ) {
						$label = $input["name"];
						if( isset( $_POST["input_".str_replace( '.', '_', $input["id"] )] ) ) {
							$value = stripslashes( $_POST["input_".str_replace('.', '_', $input["id"] )] );
						}
					}
					if ($value != '') {
						$submitted_data[$label] = $value;
					}		
					$value = "";  // Clear $value because we're setting $submitted_data within this loop instead of within the fields loop
			   }
		   }
		} elseif( $field["type"] == "multiselect" ) {
			if( isset( $field["inputName"] ) && ($field["inputName"] != '') ) {
				$label = $field["inputName"];
				if( isset( $_POST["input_" . $field["id"]] ) ) {
					$value_array = $_POST["input_" . $field["id"]];
					foreach( $value_array as $multiselect_value ) {
						if( $value != '' ) { $value .= Chr(13); }
						$value .= stripslashes( $multiselect_value );
					}
				}
			}
		} elseif( $field["type"] == "time" ) {	
			if( isset( $field["inputName"] ) && ($field["inputName"] != '') ) {
				$label = $field["inputName"];
				$hours = 0;
				$minutes = 0;
				$ampm = '';
				if( isset( $_POST["input_" . $field["id"]][0] ) ) {
					$hours = stripslashes( $_POST["input_" . $field["id"]][0] );
				}
				if( isset( $_POST["input_" . $field["id"]][1] ) ) {
					$minutes = stripslashes( $_POST["input_" . $field["id"]][1] );
				}
				if( isset( $_POST["input_" . $field["id"]][2] ) ) {
					$ampm = stripslashes( $_POST["input_" . $field["id"]][2] );
				}
				$value = $hours.":".$minutes;
				if( $ampm != '' ) { $value .= ' '.$ampm; }
			}
		} else {  // This is a single-input field
			if( isset( $field["inputName"] ) && ($field["inputName"] != '') ) {
				$label = $field["inputName"];
				if( isset( $_POST["input_" . $field["id"]] ) ) {
					$value = stripslashes( $_POST["input_" . $field["id"]] );
				}
			}
		}
		if ($value != '') {
			$submitted_data[$label] = $value;
		}	
	}
	
	//if( Count( $submitted_data ) == 0 ) { Return; }
	
	$submitted_data =  array();
	$submitted_data["SourceAPIVersion"] = self::$version;
	$submitted_data["source"] = "http" . (($_SERVER['SERVER_PORT']==443) ? "s://" : "://") . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	$submitted_data["gavid"] = $_COOKIE["__utma"];
	$submitted_data["logger"] = $_COOKIE["logger"];	
	$submitted_data["ipaddress"] = $_SERVER['REMOTE_ADDR'];
	$submitted_data["apikey"] = $settings["key"];	
	$submitted_data["cid"] = $settings["clientid"];
	$submitted_data["form_type"] = $form["title"];

	$strFprint = $_SERVER["HTTP_USER_AGENT"]."|";
	$strFprint.= $_SERVER["HTTP_ACCEPT_LANGUAGE"]."|";
	$strFprint.= $_SERVER["HTTP_ACCEPT_ENCODING"];
	$submitted_data["fprint"] = stripslashes($strFprint); //fprint

	if (strlen($form["title"]) ==0) {
		$submitted_data["form_type"] = "contact form";
	}

	$form_id = $form["id"];
	$form_fields = self::get_form_fields($form_id);

	$intValueCount = 0;
	foreach ($form_fields as $field) {
		$field_id = $field[0];
		$field_label = $field[1];		
		$var = "input_".$field_id;
		$strFieldValue = stripslashes(trim($_POST[$var]));
		$strFieldName = $settings[$form_id."|".$field_id];
		if (($strFieldName == "newsletter") || ($strFieldName == "contact_optin")) {
			$var = "input_".$field_id."_1";
			if (strlen($_POST[$var])>0) {
				$strFieldValue = 1; //$_POST[$var];
			}
		}
		if (strlen($strFieldValue)>0) {
			$submitted_data[$strFieldName] = $strFieldValue;	
			$intValueCount++;
		}
	}
	//CUSTOM FOR ONLINESUCCES.NL BY FH
	if ($submitted_data["cid"] == "1002") {
		if (($form_id == 9) || ($form_id == 8)) {
			$submitted_data["newsletter"] = 1;
		}
	}
	//print_r($submitted_data); //DEBUG
	//exit();

	if( $intValueCount == 0 ) { Return; } //no values found so we dont need to do an API call
	
	/*
	//OLD PHP CODE BY FH
	$submitted_data["contact"] = stripslashes(trim($_POST["input_2"])); //name
	$submitted_data["email1"] = stripslashes(trim($_POST["input_8"])); //email	
	$submitted_data["phone1"] = stripslashes(trim($_POST["input_4"])); //phone
	$submitted_data["remarks"] = stripslashes($_POST["input_5"]); //remarks

	if (strlen(trim($_POST["input_7_1"]))>0) {
		$submitted_data["newsletter"] = 1;
	}
	$submitted_data["newsletter"] = stripslashes(trim($_POST["input_7.1"])); //newsletter	
	if ($form["id"]=="7") { //DEMO FORM
		$submitted_data["contact"] = stripslashes(trim($_POST["input_1"])); //name
		$submitted_data["email1"] = stripslashes(trim($_POST["input_2"])); //email	
		$submitted_data["phone1"] = stripslashes(trim($_POST["input_3"])); //phone
		$submitted_data["company"] = stripslashes(trim($_POST["input_4"])); //companyname
		if (strlen(trim($_POST["input_5_1"]))>0) {
			$submitted_data["newsletter"] = 1;
		}
	}
	elseif ($form["id"]=="6") { //BROCHURE FORM
		$submitted_data["company"] = stripslashes(trim($_POST["input_1"])); //companyname
		$submitted_data["contact"] = stripslashes(trim($_POST["input_2"])); //name
		$submitted_data["email1"] = stripslashes(trim($_POST["input_3"])); //email	
		$submitted_data["phone1"] = stripslashes(trim($_POST["input_4"])); //phone
		if (strlen(trim($_POST["input_5_1"]))>0) {
			$submitted_data["newsletter"] = 1;
		}
		if (strlen(trim($_POST["input_6_1"]))>0) {
			$submitted_data["customfield1"] = "Contact me for more information";	
			$submitted_data["contact_optin"] = 1;	
		}
	}
	elseif ($form["id"]=="8") { //DOWNLOAD SEO SUCCES GIDS
		$submitted_data["contact"] = stripslashes(trim($_POST["input_1"])); //name
		$submitted_data["email1"] = stripslashes(trim($_POST["input_4"])); //email	
		$submitted_data["phone1"] = "";
		$submitted_data["newsletter"] = 1;
	}	
	elseif ($form["id"]=="9") { //DOWNLOAD CONTENT MARKETING GIDS
		$submitted_data["contact"] = stripslashes(trim($_POST["input_1"])); //name
		$submitted_data["email1"] = stripslashes(trim($_POST["input_2"])); //email	
		$submitted_data["phone1"] = "";
		$submitted_data["newsletter"] = 1;
	}	
	else {
		$submitted_data["inquiry_type"] = stripslashes($_POST["input_1"]); //selectbox		
	}
	*/	

	if( isset( $settings["date_format"] ) && ($settings["date_format"] != '') ) {
		$submitted_data["DateFormat"] = $settings["date_format"];
	}
	if( isset( $settings["decimal_separator"] ) && ($settings["decimal_separator"] != '') ) {
		$submitted_data["DecimalSeparator"] = $settings["decimal_separator"];
	}
	
	if( isset($settings["debug"]) && ($settings["debug"] == 'on' ) ) {  // Send debugging email
		ob_start();
		var_dump($submitted_data);
		mail( $strDebugMail, '3 Online Success software API for Gravity Forms about to send', ob_get_contents() );
		ob_end_clean();
	}	
	
	// Post the submitted values to the Online Success software API
	$response = wp_remote_post( "https://app.onlinesucces.nl/api/index.php", array(
		'method' => 'POST',
		'timeout' => 45,
		'redirection' => 5,
		'body' => $submitted_data,
		)
	);
	
	
	if( isset($settings["debug"]) && ($settings["debug"] == 'on' ) ) {  // Send debugging email
		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			mail( $strDebugMail, '4 Online Success software API for Gravity Forms sending error', $error_message );
		} else {
			ob_start();
			var_dump($response);
			mail( $strDebugMail, '5 Online Success software API for Gravity Forms sent', ob_get_contents() );
			ob_end_clean();
		}
	}
	
	
}  // end of lb_gform_pre_submission




public static function plugin_settings_link( $links ) {  // modify the link by unshifting the array
	$settings_link = '<a href="' . admin_url( 'admin.php?page=gf_settings&subview=Light+Blue+API' ) . '">Settings</a>';
	array_unshift( $links, $settings_link );
	return $links;
}


public static function deactivate(){
	// Remove stored settings
	delete_option("os6_lead_manager_settings");

	// Deactivate plugin
	$plugin = self::$path;
	deactivate_plugins($plugin);
	update_option('recently_activated', array($plugin => time()) + (array)get_option('recently_activated'));
}

public static function display_gravity_forms_status() {
	if( self::is_gravity_forms_installed( True ) == 1) {  // Installed, so check version requirements
		if( self::is_gravityforms_supported() == False ) {
			$message = "<p>The ".self::$name." plugin requires <a href='http://www.gravityforms.com' target='_blank'>Gravity Forms</a> version ".self::$min_gravityforms_version.", and you are using version ".GFCommon::$version.". Please update Gravity Forms.</p>";
			print "<div id='message' class='updated'>".$message."</div>";
		}
	}
}

public static function is_gravity_forms_installed( $printStatus = False ) {
	$message = '';
	$installed = 0;
	if(!class_exists('RGForms')) {
		if(file_exists(WP_PLUGIN_DIR.'/gravityforms/gravityforms.php')) {
			$installed = 2;
			$message = "<p>Gravity Forms is installed but not active. Please activate the Gravity Forms plugin on the <a href='".wp_nonce_url(admin_url('plugins.php'))."'>plugin settins page</a> to use the ".self::$name." plugin.</p>";
		} else {
			$installed = 0;
			$message = "<p>The ".self::$name." plugin requires the <a href='http://www.gravityforms.com' target='_blank'>Gravity Forms</a> plugin.</p>";
		}
	} else {
		$installed = 1;
	}
	if(($message != '') && ($printStatus == True)) {
			print "<div id='message' class='updated'>".$message."</div>";
		}
	return $installed;
}

private static function is_gravityforms_supported(){
	if(class_exists("GFCommon")){
		$is_correct_version = version_compare(GFCommon::$version, self::$min_gravityforms_version, ">=");
		return $is_correct_version;
	}
	else{
		return false;
	}
}

	private static function get_field_mapping($config = array(), $form_id, $merge_vars, $settings){

		$usedFields = array();
		$str = $custom = $standard = '';

		//getting list of all fields for the selected form
		$form_fields = self::get_form_fields($form_id);

		$str = "<table cellpadding='0' cellspacing='0'><thead><tr><th scope='col' >Gravity Form Label</th><th scope='col'>Online Success Fields</th><th scope='col'>Field Id</th></tr></thead><tbody>";

		//foreach((array)$merge_vars as $var){
		$intCount = 0;
		foreach($form_fields as $field){
			$field_id = $field[0];
			$field_label = $field[1];				
			if (is_numeric($field_id)) {			
				$row = "<tr><td ><label>" . stripslashes( $field_label )  . "</label></td>";
				$row.= "<td >";
				//$row.= self::get_mapped_field_list($var["tag"], $selected_field, $form_fields);

				$row.= "<select name='$form_id|$field_id'>\n";
				$row.= "<option value=''></option>\n";
				foreach($merge_vars as $merge_field){
					$field_label = $merge_field["name"];
					$row.= "<option value=\"" . $field_label . "\" ";
					//$row.= selected(($form_id."|".$field_id == $field_label), true, false);
					if ($settings[$form_id."|".$field_id] == $field_label) {
						$row.= "selected";					
					}
					$row.= ">" . $field_label;
					$row.= "</option>\n";
				}
				$row.= "</select>\n";
				$row.= "</td>";

				$row.= "<td>";
				$row.= "input_".$field_id;
				$row.= "</td>";			
				$row.= "</tr>\n";			

				$str .= $row;
				$intCount++;
			}

		} // End foreach merge var.

		$str .= "</tbody></table>";

		return $str;
	}

	private static function getFieldsForObject() {
		$merge_vars[0]["name"] = "country";
		$merge_vars[1]["name"] = "company";
		$merge_vars[2]["name"] = "contact_firstname";
		$merge_vars[3]["name"] = "contact";
		$merge_vars[4]["name"] = "email1";
		$merge_vars[5]["name"] = "website";
		$merge_vars[6]["name"] = "address";
		$merge_vars[7]["name"] = "zip";
		$merge_vars[8]["name"] = "city";
		$merge_vars[9]["name"] = "state";
		$merge_vars[10]["name"] = "country";
		$merge_vars[11]["name"] = "phone1";
		$merge_vars[12]["name"] = "source";
		$merge_vars[13]["name"] = "vat";
		$merge_vars[14]["name"] = "vatname";
		$merge_vars[15]["name"] = "function";
		$merge_vars[16]["name"] = "email2";
		$merge_vars[17]["name"] = "phone2";
		$merge_vars[18]["name"] = "ipaddress";
		$merge_vars[19]["name"] = "website_source";
		$merge_vars[20]["name"] = "form_type";
		$merge_vars[21]["name"] = "gavid";
		$merge_vars[22]["name"] = "remarks";
		$merge_vars[23]["name"] = "inquiry_type";
		$merge_vars[24]["name"] = "newsletter";				
		$merge_vars[25]["name"] = "customfield1";
		$merge_vars[26]["name"] = "customfield2";
		$merge_vars[27]["name"] = "customfield3";
		$merge_vars[28]["name"] = "customfield4";
		$merge_vars[29]["name"] = "customfield5";
		$merge_vars[30]["name"] = "contact_optin";

		return $merge_vars;
	}	

	public static function get_form_fields($form_id){
		$form = RGFormsModel::get_form_meta($form_id);
		$fields = array();

		//Adding default fields
		array_push($form["fields"],array("id" => "date_created" , "label" => __("Entry Date", "gravity-forms-os6")));
		array_push($form["fields"],array("id" => "ip" , "label" => __("User IP", "gravity-forms-os6")));
		array_push($form["fields"],array("id" => "source_url" , "label" => __("Source Url", "gravity-forms-os6")));
		array_push($form["fields"],array("id" => "form_title" , "label" => __("Form Title", "gravity-forms-os6")));


		if(is_array($form["fields"])){
			//print_r ($form["fields"]);
			foreach($form["fields"] as $field){
				if(isset($field["inputs"]) && is_array($field["inputs"]) && $field['type'] !== 'checkbox' && $field['type'] !== 'select'){

					//If this is an address field, add full name to the list
					if(RGFormsModel::get_input_type($field) == "address")
						$fields[] =  array($field["id"], GFCommon::get_label($field) . " (" . _x("Full" , 'Full address label', "gravity-forms-os6") . ")");

					foreach($field["inputs"] as $input)
						$fields[] =  array($input["id"], GFCommon::get_label($field, $input["id"]));
				}
				else if(empty($field["displayOnly"])){
					$fields[] =  array($field["id"], GFCommon::get_label($field));
				}
			}
		}
		return $fields;
	}

	public static function get_mapped_field_checkbox($variable_name, $selected_field, $field){
		$field_name = "os6_map_field_" . $variable_name;
		$field_id = $field[0];
		$str =  "<input name='$field_name' id='$field_name' type='checkbox' value='$field_id'";
		$selected = $field_id == $selected_field ? " checked='checked'" : false;
		if($selected) {
			$str .= $selected;
		}

		$str .= " />";
		return $str;
	}	

}